@@ -3,8 +3,8 @@ import logging
 import urwidtrees
 
 from sen.tui.widgets.list.util import RowWidget
-from sen.tui.widgets.util import get_basic_image_markup, SelectableText
-
+from sen.tui.widgets.util import SelectableText
+from sen.tui.chunks.image import get_basic_image_markup
 
 logger = logging.getLogger(__name__)
 
@@ -13,7 +13,7 @@ class TreeNodeWidget(SelectableText):
     def __init__(self, ui, docker_image):
         self.ui = ui
         self.docker_image = docker_image
-        super().__init__(get_basic_image_markup(docker_image))
+        super().__init__(get_basic_image_markup(docker_image, with_size=True))
 
 
 class TreeBackend(urwidtrees.Tree):
